@@ -64,27 +64,15 @@ static struct inode_table_entry {
 #undef DEBUG
 #define Debug 0
 
-/* div_blocksize() and mul_blocksize() are trivial functions to avoid 64-bit
-   __udivdi3 and __muldi3 millicode routines. They only work because the ext2
-   blocksize is a multiple of 2 */
 static __u64 div_blocksize(__u64 devaddr, unsigned blocksize)
 {
-	while (blocksize > 1) {
-		devaddr >>= 1;
-		blocksize >>= 1;
-	}
-	return devaddr;
+	return devaddr / blocksize;
 }
 static __u64 mul_blocksize(__u64 devaddr, unsigned blocksize)
 {
-	while (blocksize > 1) {
-		devaddr <<= 1;
-		blocksize >>= 1;
-	}
-	return devaddr;
+	return devaddr * blocksize;
 }
 
-
 static struct ext3_extent_header *ext3_extent_header(struct ext2_inode *i)
 {
 	return (struct ext3_extent_header *)&i->i_block[0];
