@@ -443,15 +443,18 @@ interact(int *ok)
 	/* turn on firmware manufacturing mode on C8000 workstation */
 	if (numbuf[0] == 'm') { /* hidden option! */
 	    const char *model = get_machine_model();
+	    join(commandline, argc, argv, ok);
 	    if (strncmp(model, "9000/785/C8000", 14) == 0) {
 		*(unsigned char *)0xfffffff0f04300a0 = 0x4d;
 		pdc_do_reset();
 	    }
 	    printf("unknown machine - can not enable manufacturing mode\n");
+	    continue;
 	}
 
 	if (numbuf[0] == 'd') /* hidden option! */
 	{
+	    join(commandline, argc, argv, ok);
 	    Debug = !Debug;
 	    printf("Debug mode is now %s\n", Debug ? "on":"off");
 	    if (Debug)
@@ -519,6 +522,7 @@ iplmain(int is_interactive, char *initialstackptr, int started_wide)
     struct firstblock f;
     int blocked_bootdev;
     int wide;
+    int ccr_functional;
     int kern_part, rd_part;
     char kern_name[128], rd_name[128];
     char kern_fullname[128+10];
@@ -543,6 +547,14 @@ iplmain(int is_interactive, char *initialstackptr, int started_wide)
 	printf("palo loaded at %p-%p.\n", &_start, &_end);
     }
 
+    ccr_functional = pdc_coproc_cfg();
+    if (ccr_functional)
+	asm("mtctl %0,%1" : : "r" (ccr_functional), "i" (10));
+    else {
+	printf("No functional FPUs found - stopping.\n");
+	while (1) ;
+    }
+
     disk_2gb_limit = pdc_bootdisk_2GB_limit();
     printf("Boot limited to sectors below 2GB: %s\n", disk_2gb_limit ? "YES":"NO");
 
@@ -684,9 +696,14 @@ iplmain(int is_interactive, char *initialstackptr, int started_wide)
     /* If we have any failures after this, be sure we're interactive
      * for the re-start */
     interactive = 1;
+    ok = 1;
 
+    if (Debug) printf("commandline %s\n", commandline);
     strcpy(commandline,
 	    parse(commandline, &kern_part, kern_name, &rd_part, rd_name));
+    if (Debug) printf("commandline %s\n", commandline);
+    if (Debug) printf("kernel %s  part %d\n", kern_name, kern_part);
+    if (Debug) printf("rd     %s  part %d\n", rd_name, rd_part);
 
     sprintf(kern_fullname, "%d%s", kern_part, kern_name);
     chk_strcat(commandline, " palo_kernel=", CMDLINELEN, &ok);
