@@ -220,6 +220,20 @@ pdc_os_bits()
     return osbits;
 }
 
+int
+pdc_coproc_cfg(void)
+{
+    int r;
+
+    r = firmware_call(mem_pdc, PDC_COPROC, PDC_COPROC_CFG, pdc_result);
+    convert_from_wide(pdc_result);
+    if (r == PDC_OK) {
+		return pdc_result[0]; /* ccr_functional */
+        } else {
+		return 0;
+        }
+}
+
 int
 pdc_model_sysmodel(char *name)
 {
